@@ -280,7 +280,7 @@ def transformBack(obj):
                         c.addItem(i)
                 return c
             if out['type'] == "Date":
-                return datetime.datetime.fromtimestamp(out["timestamp"]/1000)
+                return datetime.fromtimestamp(out["timestamp"]/1000)
             if out['type'] == "TableDisplay":
                 if 'subtype' in out:
                     if out['subtype'] == "Dictionary":
@@ -361,7 +361,7 @@ class DataFrameEncoder(json.JSONEncoder):
             ret = obj.tolist()
             transformNaNs(ret)
             return ret
-        if type(obj) == datetime.datetime or type(obj) == datetime.date or type(obj).__name__ == 'Timestamp':
+        if type(obj) == datetime or type(obj) == datetime.date or type(obj).__name__ == 'Timestamp':
             out = {}
             out['type'] = "Date"
             out['timestamp'] = time.mktime(obj.timetuple()) * 1000
@@ -423,13 +423,13 @@ class TableDisplayWrapper(object):
         def f():
             display_html(TableDisplay(model_instance))
         return f
-    
+
+
 class BeakerX:
-    """Runtime support for Python code in BeakerX."""
-    _comm = Comm(target_name='beakerx.autotranslation')
 
     def __init__(self):
         BeakerX.pandas_display_table()
+        self._comm = None
 
     @staticmethod
     def pandas_display_default():
@@ -445,12 +445,18 @@ class BeakerX:
             val = transform(val)
             args['value'] = json.dumps(val, cls=DataFrameEncoder)
             state = {'state': args}
+        if self._comm is None:
+            self.init_autotranslation_comm()
         self._comm.send(data=state)
 
+    def init_autotranslation_comm(self):
+        self._comm = Comm(target_name='beakerx.autotranslation')
+        self._comm.open()
+
     def get(self, var):
         result = autotranslation_get(var)
         if result == 'undefined':
-            raise NameError('name \'' + var + '\' is not defined in notebook namespace')
+            raise NameError('name \'' + var + '\' is not defined on the beakerx object')
         return transformBack(json.loads(result))
 
     def set_session(self, id):
@@ -578,9 +584,14 @@ class BeakerX:
         if 'session_id' == name:
             self.__dict__['session_id'] = value
             return
+        if '_comm' == name:
+            self.__dict__['_comm'] = value
+            return
         return self.set(name, value)
 
     def __getattr__(self, name):
+        if '_comm' == name:
+            return self.__dict__['_comm']
         return self.get(name)
 
     def __contains__(self, name):
@@ -594,7 +605,7 @@ def autotranslation_update(var, val):
     session_id = get_context_session()
     port = os.environ["BEAKERX_AUTOTRANSLATION_PORT"]
     url = 'http://localhost:{0}/autotransltion/'.format(port)
-    json_data = json.dumps(transform(val))
+    json_data = json.dumps(transform(val), cls=DataFrameEncoder)
     data = {}
     data["name"] = var
     data["json"] = json_data
@@ -619,5 +630,6 @@ def get_context_session():
     kernel = get_ipython().kernel
     # if subkernel get session from extra start parameters
     if len(kernel.parent.argv) == 3:
-        return json.loads(kernel.parent.argv[2])['contextId']
+        context_json = base64.b64decode(kernel.parent.argv[2]).decode('UTF-8')
+        return json.loads(context_json)['contextId']
     return kernel.session.session
