@@ -191,3 +191,54 @@ class ColorUtils:
         alpha = min(alpha, 255.0)
         alpha = max(alpha, 0.0)
         return Color(round(red), round(green), round(blue), round(alpha))
+
+class KeyboardCodes():
+    BACKSPACE = 'BACKSPACE'
+    TAB = 'TAB'
+    ENTER = 'ENTER'
+    SHIFT = 'SHIFT'
+    CTRL = 'CTRL'
+    ALT = 'ALT'
+    PAUSE_BREAK = 'PAUSE_BREAK'
+    CAPS_LOCK = 'CAPS_LOCK'
+    ESCAPE = 'ESCAPE'
+    SPACE = 'SPACE'
+    PAGE_UP = 'PAGE_UP'
+    PAGE_DOWN = 'PAGE_DOWN'
+    END = 'END'
+    HOME = 'HOME'
+    LEFT_ARROW = 'LEFT_ARROW'
+    UP_ARROW = 'UP_ARROW'
+    RIGHT_ARROW = 'RIGHT_ARROW'
+    DOWN_ARROW = 'DOWN_ARROW'
+    INSERT = 'INSERT'
+    DELETE = 'DELETE'
+    MULTIPLY = 'MULTIPLY'
+    ADD = 'ADD'
+    SUBTRACT = 'SUBTRACT'
+    DECIMAL_POINT = 'DECIMAL_POINT'
+    DIVIDE = 'DIVIDE'
+    F1 = 'F1'
+    F2 = 'F2'
+    F3 = 'F3'
+    F4 = 'F4'
+    F5 = 'F5'
+    F6 = 'F6'
+    F7 = 'F7'
+    F8 = 'F8'
+    F9 = 'F9'
+    F10 = 'F10'
+    F11 = 'F11'
+    F12 = 'F12'
+    NUM_LOCK = 'NUM_LOCK'
+    SCROLL_LOCK = 'SCROLL_LOCK'
+    EQUAL_SIGN = 'EQUAL_SIGN'
+    COMMA = 'COMMA'
+    DASH = 'DASH'
+    PERIOD = 'PERIOD'
+    FORWARD_SLASH = 'FORWARD_SLASH'
+    GRAVE_ACCENT = 'GRAVE_ACCENT'
+    OPEN_BRACKET = 'OPEN_BRACKET'
+    BACK_SLASH = 'BACK_SLASH'
+    CLOSE_BRAKET = 'CLOSE_BRAKET'
+    SINGLE_QUOTE = 'SINGLE_QUOTE'
